.g-sentry-value-container{background-color:#f6f6f6;border:1px solid #ddd;margin:10px 0;padding:3px 9px}.g-sentry-value-container .g-sentry-value{margin-left:15px;font-family:monospace;display:inline-block}
/*$vite$:1*/